@@ -8,16 +8,13 @@ from openpectus import log_setup_colorlog
 from openpectus.aggregator.aggregator_server import AggregatorServer
 from openpectus import sentry, __version__, build_number
 
-# - add lsp thingys
-# - start (manage) lsp server instance for each client
-
-# Start env in docker
-# ../docker compose up --build
 
 log_setup_colorlog(root_loglevel=logging.INFO)
 logger = logging.getLogger("openpectus.aggregator.aggregator")
 logger.setLevel(logging.INFO)
 logging.getLogger("openpectus.protocol.aggregator_dispatcher").setLevel(logging.INFO)
+logging.getLogger("openpectus.aggregator.routers.webpush").setLevel(logging.DEBUG)
+
 
 def get_arg_parser():
     parser = ArgumentParser("Start Aggregator server")
@@ -34,6 +31,8 @@ def get_arg_parser():
                         help=f"Path to Sqlite3 database. Default: ./{AggregatorServer.default_db_filename}")
     parser.add_argument("-secret", "--secret", required=False, default=AggregatorServer.default_secret,
                         help="Engines must know this secret to connect to the aggregator")
+    parser.add_argument("-wpk", "--webpush_keys_path", required=False, default=AggregatorServer.default_webpush_keys_path,
+                        help=f"Path to directory where VAPID key files for Webpush should be stored. Default: {AggregatorServer.default_webpush_keys_path}")
     return parser
 
 
@@ -56,7 +55,7 @@ def main():
     alembic_config.set_main_option("sqlalchemy.url", f"sqlite:///{args.database}")
     command.upgrade(alembic_config, "head")
 
-    server = AggregatorServer(title, args.host, args.port, args.frontend_dist_dir, args.database, args.secret)
+    server = AggregatorServer(title, args.host, args.port, args.frontend_dist_dir, args.database, args.secret, args.webpush_keys_path)
 
     # seart aggregator server
     server.start()
