@@ -7,12 +7,12 @@ from openpectus.lang.exec.uod import UnitOperationDefinitionBase, UodCommand, Uo
 from openpectus.protocol.models import PlotConfiguration, SubPlot, PlotAxis, PlotColorRegion
 import openpectus.lang.exec.tags_impl as tags
 import openpectus.lang.exec.units as units
-from openpectus.lang.exec.units import as_float, as_int
+from openpectus.lang.exec.units import as_decimal, as_int
 
 __all__ = [
-    "HardwareLayerBase", "Register", "RegisterDirection",
-    "UnitOperationDefinitionBase", "UodCommand", "UodBuilder",
-    "RegexNumber", "RegexText", "RegexCategorical",
-    "PlotConfiguration", "SubPlot", "PlotAxis", "PlotColorRegion",
-    "tags", "units", "as_float", "as_int"
+    'HardwareLayerBase', 'Register',
+    'UnitOperationDefinitionBase', 'UodCommand', 'UodBuilder',
+    'RegexNumber', 'RegexText', 'RegexCategorical',
+    'PlotConfiguration', 'SubPlot', 'PlotAxis', 'PlotColorRegion',
+    "tags", "units", "as_decimal", "as_int"
 ]
