@@ -4,16 +4,19 @@ import logging
 import itertools
 from collections import defaultdict
 import time
+import decimal
 
 import pint
 from pint import UnitRegistry, Quantity
 
+
 cache_folder = os.path.join(os.path.dirname(__file__), "pint-cache")
 try:
-    ureg = UnitRegistry(cache_folder=cache_folder)
+    ureg = UnitRegistry(cache_folder=cache_folder, non_int_type=decimal.Decimal)  # type: ignore
 except EOFError:
     time.sleep(0.2)
-    ureg = UnitRegistry(cache_folder=cache_folder)
+    ureg = UnitRegistry(cache_folder=cache_folder, non_int_type=decimal.Decimal)  # type: ignore
+
 
 ureg.define("m3 = m**3")
 ureg.define("m2 = m**2")
@@ -22,7 +25,6 @@ ureg.define("cm2 = cm**2")
 ureg.define("LMH = mm/h")
 ureg.define("wt = 1")
 ureg.define("vol = 1")
-ureg.define("AU = [absorbance]")
 Q_ = Quantity
 
 logger = logging.getLogger(__name__)
@@ -43,7 +45,7 @@ QUANTITY_UNIT_MAP.update({
     'frequency': ['Hz', 'kHz'],
     'pressure': ['Pa', 'bar', 'pascal'],            # Note: pint prefers pascal over Pa so we define both.
     'mass flow rate': ['kg/h', 'g/s', 'g/min', 'g/h'],
-    'electrical conductance': ['mS/cm'],
+    'conductivity': ['mS/cm', 'µS/cm'],
     'percentage': ['%', 'vol%', 'wt%', 'mol%'],     # Custom quantity but supported by pint
     'column volume': ['CV'],                        # Custom quantity
     'absorbance': ['AU', 'mAU', 'milliAU'],
@@ -70,11 +72,14 @@ QUANTITY_PINT_MAP: dict[str, str] = {
     'flux': '[length] / [time]',
     'permeability': '[length] ** 2 * [time] / [mass]',
     'absorbance': '[absorbance]',
+    'conductivity': '[conductivity]',
 }
 """ Map quantity names to pint dimensions or None if not a pint dimension. """
 
-FLOAT_COMPARE_DELTA = 0.01
-""" The precision to use when comparing float values for equality. """
+# build list of all supported units
+_supported_units: list[None | str] = [None]
+for v in QUANTITY_UNIT_MAP.values():
+    _supported_units.extend(v)
 
 # These units are not stored as a tag unit but as a tag value in the Base tag,
 # so they need special treatment.
@@ -161,14 +166,14 @@ def is_supported_unit(unit: str) -> bool:
 def get_volume_units():
     return QUANTITY_UNIT_MAP['volume']
 
-def convert_value_to_unit(value: float | int, source_unit: str, target_unit: str) -> float:
+def convert_value_to_unit(value: decimal.Decimal | float | int, source_unit: str, target_unit: str) -> float:
     """ Convert a value with a unit to the value in another unit.
 
     Raises ValueError if the units are not compatible.
     """
     try:
         val = ureg.Quantity(value, source_unit).to(target_unit).magnitude
-        return val
+        return float(val)
     except pint.DimensionalityError:
         raise ValueError(f"Cannot convert between units '{source_unit}' and '{target_unit}'")
 
@@ -191,10 +196,16 @@ def get_compatible_unit_names(unit: str | None) -> list[str]:
     if unit is None:
         return [""]
 
+    if unit in ['vol%', 'wt%', 'mol%']:
+        return [unit]
+
     quantity_name = get_unit_quantity_name(unit)
     assert quantity_name is not None and quantity_name != ""
 
-    pint_mapping = QUANTITY_PINT_MAP.get(quantity_name)
+    if quantity_name.startswith("[") and quantity_name.endswith("]"):
+        quantity_name = quantity_name[1:-2]
+
+    pint_mapping = QUANTITY_PINT_MAP.get(quantity_name[1:-2])
     if pint_mapping is None:
         # non-pint unit, return all units of this quantity name
         return QUANTITY_UNIT_MAP[quantity_name]
@@ -256,7 +267,7 @@ def compare_values(op: str, value_a: str, unit_a: str | None, value_b: str, unit
 
     is_pint_units = is_pint()
     if is_pint_units:
-        fval_a, fval_b = as_float(value_a), as_float(value_b)
+        fval_a, fval_b = as_decimal(value_a), as_decimal(value_b)
         if fval_a is None:
             raise ValueError("Cannot compare values, first value is missing or not numeric")
         if fval_b is None:
@@ -276,7 +287,7 @@ def compare_values(op: str, value_a: str, unit_a: str | None, value_b: str, unit
         if op in ['<', '<=', '>', '>=']:  # these operators only make sence for numeric values
             assert isinstance(quantity_a, str), f"quantity_a '{quantity_a}' should be a str here"
             assert isinstance(quantity_b, str), f"quantity_b '{quantity_b}' should be a str here"
-            quantity_a, quantity_b = as_float(quantity_a), as_float(quantity_b)
+            quantity_a, quantity_b = as_decimal(quantity_a), as_decimal(quantity_b)
             if quantity_a is None:
                 raise ValueError("Cannot compare values, first value is missing or not numeric")
             if quantity_b is None:
@@ -285,7 +296,7 @@ def compare_values(op: str, value_a: str, unit_a: str | None, value_b: str, unit
             # if both are numerical, perform a numerical comparison
             assert isinstance(quantity_a, str), f"quantity_a '{quantity_a}' should be a str here"
             assert isinstance(quantity_b, str), f"quantity_b '{quantity_b}' should be a str here"
-            quantity_a_f, quantity_b_f = as_float(quantity_a), as_float(quantity_b)
+            quantity_a_f, quantity_b_f = as_decimal(quantity_a), as_decimal(quantity_b)
             if quantity_a_f is not None and quantity_b_f is not None:
                 quantity_a, quantity_b = quantity_a_f, quantity_b_f
 
@@ -296,13 +307,11 @@ def compare_values(op: str, value_a: str, unit_a: str | None, value_b: str, unit
             case '<=':
                 result = quantity_a <= quantity_b  # type: ignore
             case '=' | '==':
-                if isinstance(quantity_a, Quantity) and isinstance(quantity_b, Quantity):
-                    diff = quantity_a - quantity_b
-                    result = abs(diff.magnitude) < FLOAT_COMPARE_DELTA
-                elif isinstance(quantity_a, float) and isinstance(quantity_b, float):
-                    result = abs(quantity_a - quantity_b) < FLOAT_COMPARE_DELTA
-                else:
-                    result = quantity_a == quantity_b
+                if is_pint_units:
+                    assert isinstance(quantity_a, Q_)
+                    assert isinstance(quantity_b, Q_)
+                    quantity_b = quantity_b.to(quantity_a.units)
+                result = quantity_a == quantity_b
             case '>':
                 result = quantity_a > quantity_b  # type: ignore
             case '>=':
@@ -319,19 +328,20 @@ def compare_values(op: str, value_a: str, unit_a: str | None, value_b: str, unit
     assert isinstance(result, bool), f"Comparison result was not type bool but {type(result)}"
     return result
 
-def as_float(value: str) -> float | None:
+def as_decimal(value: str) -> decimal.Decimal | None:
     """ Parse string value as a float and return it. If the value is not a number, return None. """
     try:
-        return float(value)
+        return decimal.Decimal(value)
     except Exception:
         return None
 
 def as_int(value: str) -> int | None:
     """ Parse string value as int and return it. If the value is not an int, return None. """
-    fval = as_float(value)
-    if fval is not None:
-        if fval.is_integer():
-            return int(fval)
+    dval = as_decimal(value)
+    if dval is not None:
+        numerator, denominator = dval.as_integer_ratio()
+        if denominator == 1:
+            return int(dval)
     return None
 
 def _get_pint_unit(unit: str | None) -> pint.Unit | None:
